@@ -7,7 +7,7 @@
 
 #include "httpsubmit.h"
 
-#include <KIO/Job>
+#include <KIO/TransferJob>
 
 namespace KCDDB
 {
